pyxmpp2.stanzapayload.XMLPayload

Package pyxmpp2 :: Module stanzapayload :: Class XMLPayload |
[hide private]

# Class XMLPayload

Transparent XML payload for stanza.

This object can be used for any stanza payload. It doesn't decode the XML element, but instead keeps it in the ElementTree format.

Nested Classes | [hide private]
Inherited from `interfaces.StanzaPayload`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, data) x.__init__(...) initializes x; see help(type(x)) for signature |
`ElementTree.Element` |
as_xml(self) Return the XML representation of the payload. |
Inherited from `interfaces.StanzaPayload`: `copy` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `interfaces.StanzaPayload`: `__abstractmethods__` Inherited from `interfaces.StanzaPayload` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Instance Variables | [hide private]
`ElementTree.Element` | element the wrapped element
`unicode` | xml_element_name qualified name of the wrapped element

Properties | [hide private]
| handler_key Return xml_element_name as the extra key for stanza handlers.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, data) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### as_xml(self) |
Return the XML representation of the payload. Returns: `ElementTree.Element` Overrides: interfaces.StanzaPayload.as_xml (inherited documentation)

Property Details | [hide private]

### handler_key Return xml_element_name as the extra key for stanza handlers. Get Method: unreachable.handler_key(self) - Return `xml_element_name` as the extra key for stanza handlers.